==> slapos.recipe.template-2.0.tar.gz: slapos.recipe.template-2.0/slapos/recipe/template/tests.py <==
##############################################################################
#
# Copyright (c) 2010 Vifib SARL and Contributors. All Rights Reserved.
#
# WARNING: This program as such is intended to be used by professional
# programmers who take the whole responsibility of assessing all potential
# consequences resulting from its eventual inadequacies and bugs
# End users who are looking for a ready-to-use solution with commercial
# guarantees and support are strongly adviced to contract a Free Software
# Service Company
#
# This program is Free Software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 3
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
##############################################################################

import unittest

import zc.buildout.testing
from zope.testing import doctest, renormalizing

def setUp(test):
  zc.buildout.testing.buildoutSetUp(test)
  zc.buildout.testing.install_develop('slapos.recipe.template', test)
  zc.buildout.testing.install('zope.testing', test)

checker = renormalizing.RENormalizing([
    zc.buildout.testing.normalize_path,
  ]
)

def test_suite():
  files = ['README.txt',
          ]
  return unittest.TestSuite([doctest.DocFileSuite(filename, setUp=setUp,
                               tearDown=zc.buildout.testing.buildoutTearDown,
                               optionflags=doctest.ELLIPSIS, checker=checker)
                             for filename in files])

if __name__ == '__main__':
  unittest.main(defaultTest='test_suite')

==> slapos.recipe.template-2.4.2.tar.gz: slapos.recipe.template-2.4.2/slapos/recipe/template/tests.py <==
##############################################################################
#
# Copyright (c) 2010-2012 Vifib SARL and Contributors. All Rights Reserved.
#
# WARNING: This program as such is intended to be used by professional
# programmers who take the whole responsibility of assessing all potential
# consequences resulting from its eventual inadequacies and bugs
# End users who are looking for a ready-to-use solution with commercial
# guarantees and support are strongly adviced to contract a Free Software
# Service Company
#
# This program is Free Software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 3
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
##############################################################################
import doctest
import unittest
from zc.buildout import testing

def setUp(test):
  testing.buildoutSetUp(test)
  testing.install_develop('slapos.recipe.template', test)

def test_suite():
  return unittest.TestSuite([
    doctest.DocFileSuite(
      filename,
      setUp=setUp,
      tearDown=testing.buildoutTearDown,
      optionflags=doctest.ELLIPSIS,
    ) for filename in [
      'README.txt',
      'README.jinja2.txt',
    ]
  ])

if __name__ == '__main__':
  unittest.main(defaultTest='test_suite')
